pub struct RedisChannelListener<T> { /* private fields */ }Available on crate feature
redis only.Expand description
A listener to receive messages from a redis channel via pubsub.
Implementations
Sourceimpl<T: Serialize + DeserializeOwned> RedisChannelListener<T>
impl<T: Serialize + DeserializeOwned> RedisChannelListener<T>
Sourcepub async fn recv(&mut self) -> Option<T>
pub async fn recv(&mut self) -> Option<T>
Get a new message from the channel. The outer None indicates the channel has been closed erroneously, or the internal data could not be coerced to the target type. In either case, something’s gone wrong, an exception will probably have been recorded too.